#define pre pre2

%define subrel 2
%define rel 1

Summary:	A program for synchronizing files over a network
Name:		rsync
Version: 	3.2.7
Release:	%mkrel %{?pre:0.%{pre}.%{rel}}%{?!pre:%{rel}}
Group:		Networking/File transfer
License:	GPLv3+
URL:		https://rsync.samba.org/
Source0:	https://download.samba.org/pub/rsync/%{?pre:src-previews}/%{name}-%{version}%{?pre}.tar.gz
Source1:	https://download.samba.org/pub/rsync/rsync.html
Source2:	https://download.samba.org/pub/rsync/rsyncd.conf.html
Source4:	https://download.samba.org/pub/rsync/%{?pre:src-previews}/%{name}-%{version}%{?pre}.tar.gz.asc
Source5:	https://download.samba.org/pub/rsync/%{?pre:src-previews}/%{name}-patches-%{version}%{?pre}.tar.gz
Source6:	https://download.samba.org/pub/rsync/%{?pre:src-previews}/%{name}-patches-%{version}%{?pre}.tar.gz.asc
Source12:	rsyncd.socket
Source13:	rsyncd.service
Source14:	rsyncd.conf
Source15:	rsyncd.sysconfig
Source16:	rsyncd@.service
Patch0:		CVE-2024-12084-0001-Some-checksum-buffer-fixes.patch
Patch1:		CVE-2024-12084-0002-Another-cast-when-multiplying-integers.patch
Patch2:		CVE-2024-12085-0001-prevent-information-leak-off-the-stack.patch
Patch3:		CVE-2024-12086-0001-refuse-fuzzy-options-when-fuzzy-not-selected.patch
Patch4:		CVE-2024-12086-0002-added-secure_relative_open.patch
Patch5:		CVE-2024-12086-0003-receiver-use-secure_relative_open-for-basis-file.patch
Patch6:		CVE-2024-12086-0004-disallow-.-elements-in-relpath-for-secure_relative_o.patch
Patch7:		CVE-2024-12087-0001-Refuse-a-duplicate-dirlist.patch
Patch8:		CVE-2024-12087-0002-range-check-dir_ndx-before-use.patch
Patch9:		CVE-2024-12088-0001-make-safe-links-stricter.patch
Patch10:	CVE-2024-12747-0001-fixed-symlink-race-condition-in-sender.patch
Patch11:	fix_flag_got_dir_flist_collision.patch
BuildRequires:	pkgconfig(libxxhash)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(popt)
BuildRequires:	libacl-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	acl
Recommends:	openssh-clients

%define backup_patches 1

%{?_with_patches:%define backup_patches 1}
%{?_without_patches:%define backup_patches 0}

%description
Rsync uses a quick and reliable algorithm to very quickly bring
remote and host files into sync.  Rsync is fast because it just
sends the differences in the files over the network (instead of
sending the complete files). Rsync is often used as a very powerful
mirroring process or just as a more capable replacement for the
rcp command.  A technical report which describes the rsync algorithm
is included in this package.

Install rsync if you need a powerful mirroring program.
%if %backup_patches
This rpm has patches applied from rsync tree to add these options:
  --backup-deleted
  --backup-dir-dels=DIR
  --suffix-dels=SUFFIX

Rebuild the source rpm with `--without patches' if you don't  want these patches
%endif

%prep
%if %backup_patches
%setup -q -D -b 5 -n %{name}-%{version}%{?pre}
%__patch -p1 -b -z .deleted < patches/backup-deleted.diff
%__patch -p1 -b -z .dir-del < patches/backup-dir-dels.diff
%else
%setup -q -n %{name}-%{version}%{?pre}
%endif
%autopatch -p1

%build
%serverbuild
autoreconf -vfi
rm -f config.h

%configure \
	--enable-acl-support \
	--without-included-zlib \
	--with-nobody-group=nogroup \
	--disable-simd

%make_build reconfigure

#make sure we use external zlib
rm -rf zlib

%make_build proto
%make_build

%check
rm -f testsuite/devices-fake.test
touch testsuite/devices-fake.test
rm -f testsuite/devices.test
rm -f testsuite/backup.test
%__make test

%install
%make_install

install -m644 %{SOURCE1} %{SOURCE2} .

install -D -m644 %{SOURCE12} %{buildroot}%{_unitdir}/rsyncd.socket
install -D -m644 %{SOURCE13} %{buildroot}%{_unitdir}/rsyncd.service
install -D -m644 %{SOURCE14} %{buildroot}%{_sysconfdir}/rsyncd.conf
install -D -m644 %{SOURCE15} %{buildroot}%{_sysconfdir}/sysconfig/rsyncd
install -D -m644 %{SOURCE16} %{buildroot}%{_unitdir}/rsyncd@.service

%files
%doc tech_report.tex README.md *html NEWS.md
%doc support/rrsync
%{_bindir}/rsync*
%{_mandir}/man1/rsync*.1*
%{_mandir}/man5/rsyncd.conf.5*
%config(noreplace) %{_sysconfdir}/rsyncd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/rsyncd
%{_unitdir}/rsyncd.socket
%{_unitdir}/rsyncd.service
%{_unitdir}/rsyncd@.service


%changelog
* Mon Jan 20 2025 ns80 <ns80> 3.2.7-1.2.mga9
+ Revision: 2140045
- add a patch from Ubuntu to fix a regression introduced by the fixes for CVE-2024-1208[4-8] and CVE-2024-12747 (mga#33920)
- add patches from Ubuntu for CVE-2024-1208[4-8] and CVE-2024-12747 (mga#33920)

* Fri Oct 21 2022 kekepower <kekepower> 3.2.7-1.mga9
+ Revision: 1898130
- Update to version 3.2.7

* Sat Sep 10 2022 papoteur <papoteur> 3.2.6-1.mga9
+ Revision: 1886403
- new 3.2.6

* Mon Aug 15 2022 kekepower <kekepower> 3.2.5-1.mga9
+ Revision: 1877699
- Update to version 3.2.5 final

* Thu Aug 11 2022 wally <wally> 3.2.5-0.pre2.1.mga9
+ Revision: 1877050
- new version 3.2.5pre2 to fix CVE-2022-29154 (mga#30696)

* Mon Apr 18 2022 kekepower <kekepower> 3.2.4-1.mga9
+ Revision: 1851448
- Update to version 3.2.4

* Wed Mar 23 2022 umeabot <umeabot> 3.2.3-4.mga9
+ Revision: 1821986
- Mageia 9 Mass Rebuild

* Sun Oct 03 2021 joequant <joequant> 3.2.3-3.mga9
+ Revision: 1748696
- update rsync
- update with new ssl
+ wally <wally>
- rebuild for openssl 3.0.0
+ luigiwalser <luigiwalser>
- 3.2.3
- acl patch no longer exists
- add prerequisite patch for remaining backup patch
- change patch references in SPEC to refer to backup patches

* Sat Jul 25 2020 mokraemer <mokraemer> 3.2.2-2.mga8
+ Revision: 1608980
- rebuild increase rel for backports

* Sun Jul 05 2020 daviddavid <daviddavid> 3.2.2-1.mga8
+ Revision: 1602453
- new version: 3.2.2

* Tue Jun 23 2020 daviddavid <daviddavid> 3.2.1-1.mga8
+ Revision: 1598643
- new version: 3.2.1

* Sat Jun 20 2020 kekepower <kekepower> 3.2.0-1.mga8
+ Revision: 1598142
- Update to version 3.2.0
- Remove Patches 0 and 7, fixed upstream differently

* Tue Feb 25 2020 mokraemer <mokraemer> 3.1.3-5.mga8
+ Revision: 1550442
- fix compilation issue
- remove internal zlib dependency, use system zlib

* Sat Feb 15 2020 umeabot <umeabot> 3.1.3-4.mga8
+ Revision: 1525988
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Mar 04 2019 mokraemer <mokraemer> 3.1.3-3.mga7
+ Revision: 1371433
- Fix vanished file bug, (mga#21395, smb#12569)

* Sun Sep 23 2018 umeabot <umeabot> 3.1.3-2.mga7
+ Revision: 1300860
- Mageia 7 Mass Rebuild

* Tue Apr 17 2018 kekepower <kekepower> 3.1.3-1.mga7
+ Revision: 1219720
- Update to version 3.1.3
- Remove CVE patches

* Sun Jan 28 2018 luigiwalser <luigiwalser> 3.1.2-4.mga7
+ Revision: 1197860
- add patch from ubuntu to fix CVE-2018-5764

* Tue Dec 19 2017 ns80 <ns80> 3.1.2-3.mga7
+ Revision: 1183446
- add patch from Debian for CVE-2017-16548 (mga#22216)

* Mon Dec 11 2017 ns80 <ns80> 3.1.2-2.mga7
+ Revision: 1182182
- add patches for CVE-2017-1743[34] (mga#22161)

* Tue Dec 22 2015 luigiwalser <luigiwalser> 3.1.2-1.mga6
+ Revision: 913289
- 3.1.2
- remove upstreamed CVE patches

* Thu Oct 15 2015 luigiwalser <luigiwalser> 3.1.1-6.mga6
+ Revision: 891901
- rediff upstream patch to fix same issue as CVE-2014-8242 from librsync

* Tue Feb 10 2015 luigiwalser <luigiwalser> 3.1.1-5.mga5
+ Revision: 814548
- add upstream patch to fix CVE-2014-9512
- fix use of setup macro so that patches actually get applied

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-4.mga5
+ Revision: 748531
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-3.mga5
+ Revision: 688728
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Jul 03 2014 tarakbumba <tarakbumba> 3.1.1-2.mga5
+ Revision: 642866
- Enable included zlib for backwards compability. Fixes mga#13669

* Mon Jun 23 2014 luigiwalser <luigiwalser> 3.1.1-1.mga5
+ Revision: 638860
- 3.1.1
- rediff patch 0
- remove upstreamed patch 1

* Tue Apr 15 2014 luigiwalser <luigiwalser> 3.1.0-7.mga5
+ Revision: 615166
- add upstream patch to fix CVE-2014-2855

* Mon Mar 03 2014 luigiwalser <luigiwalser> 3.1.0-6.mga5
+ Revision: 598910
- add rsync service template unit (mga#12925)

* Tue Dec 24 2013 dams <dams> 3.1.0-5.mga4
+ Revision: 560286
- suggests 'openssh-clients' as spotted on mga#11564

* Mon Oct 21 2013 umeabot <umeabot> 3.1.0-4.mga4
+ Revision: 538428
- Mageia 4 Mass Rebuild

* Mon Sep 30 2013 fwang <fwang> 3.1.0-3.mga4
+ Revision: 489596
- update man pages in html format

* Mon Sep 30 2013 fwang <fwang> 3.1.0-2.mga4
+ Revision: 489426
- update file list
- sync with fedora to use systemd settings for rsyncd
- use makeinstall_std
- cleanup spec

* Mon Sep 30 2013 fwang <fwang> 3.1.0-1.mga4
+ Revision: 489417
- new version 3.1.0

* Mon Jan 14 2013 umeabot <umeabot> 3.0.9-2.mga3
+ Revision: 380540
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 24 2011 fwang <fwang> 3.0.9-1.mga2
+ Revision: 147169
- new version 3.0.9

* Sat Apr 02 2011 ahmad <ahmad> 3.0.8-1.mga1
+ Revision: 79830
- update to 3.0.8
- don't disable lutime:
  o we have a recent enough kernel/glibc (and ideally Mageia doesn't officially
    support upgrading from 2008.x)
  o upstream now falls back to utime if lutime function is not around on the system
+ nanardon <nanardon>
- kill mandriva reference
- imported package rsync


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 3.0.7-2mdv2011.0
+ Revision: 607379
- rebuild

  + Michael Scherer <misc@mandriva.org>
    - fix License

* Fri Jan 01 2010 Funda Wang <fwang@mandriva.org> 3.0.7-1mdv2010.1
+ Revision: 484808
- new version 3.0.7

* Tue May 12 2009 Frederik Himpe <fhimpe@mandriva.org> 3.0.6-1mdv2010.0
+ Revision: 374977
- update to new version 3.0.6

* Sat Jan 03 2009 Olivier Thauvin <nanardon@mandriva.org> 3.0.5-1mdv2009.1
+ Revision: 323612
- 3.0.5

* Mon Dec 01 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.4-2mdv2009.1
+ Revision: 308829
- provide rrsync in %%doc
- Patch0: new options not handle by the rrsync script

* Sun Sep 07 2008 Frederik Himpe <fhimpe@mandriva.org> 3.0.4-1mdv2009.0
+ Revision: 282417
- Update to new version 3.0.4

  + Olivier Thauvin <nanardon@mandriva.org>
    - add NEWS, OLDNEWS as doc files

* Mon Jun 30 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.3-1mdv2009.0
+ Revision: 230334
- 3.0.3

* Sat Apr 12 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.2-1mdv2009.0
+ Revision: 192620
- 3.0.2 (security fix)

* Wed Mar 19 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-4mdv2008.1
+ Revision: 189063
- revert last change, broken patch, and anyway there's nothing to avoid issue w/o breaking rsync, -e is not used on server side anyway

* Wed Mar 19 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-3mdv2008.1
+ Revision: 188985
- avoid -e call on server because some ssh can have restriction on it (ask by blino)

* Mon Mar 10 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-2mdv2008.1
+ Revision: 183191
- fix segfault (#38730)

* Sun Mar 02 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-1mdv2008.1
+ Revision: 177527
- 3.0.0 final

* Wed Feb 20 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre10.1mdv2008.1
+ Revision: 173168
- 3.0.0 pre10
- update html page

* Mon Feb 11 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre9.1mdv2008.1
+ Revision: 165088
- 3.0.0 pre9

* Wed Feb 06 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre8.2mdv2008.1
+ Revision: 163178
- put back dir-del patch
- kill the log_on_failure USERID making xinetd performing a useless ident request

* Sat Jan 12 2008 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre8.1mdv2008.1
+ Revision: 150064
- 3.0.0 pre8

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre7.1mdv2008.1
+ Revision: 121645
- 3.0.0pre7

* Wed Nov 28 2007 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre6.0.1mdv2008.1
+ Revision: 113711
- 3.0.0 pre6

* Sat Nov 10 2007 Olivier Thauvin <nanardon@mandriva.org> 3.0.0-0.pre5.1mdv2008.1
+ Revision: 107440
- 3.0.0 pre5
- prepare work for pre release

* Sun Aug 26 2007 Olivier Thauvin <nanardon@mandriva.org> 2.6.9-5mdv2008.0
+ Revision: 71493
- fix #32654, eg disable lutimes()

* Sun Aug 19 2007 Olivier Thauvin <nanardon@mandriva.org> 2.6.9-4mdv2008.0
+ Revision: 66537
- CVE-2007-4091

* Wed Aug 15 2007 Olivier Thauvin <nanardon@mandriva.org> 2.6.9-3mdv2008.0
+ Revision: 63600
- fix --acls + --delete (#32411)

* Thu Jun 28 2007 Andreas Hasenack <andreas@mandriva.com> 2.6.9-2mdv2008.0
+ Revision: 45571
- rebuild with new serverbuild macro (-fstack-protector-all)


* Tue Nov 07 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.9-1mdv2007.0
+ Revision: 77064
- 2.6.9
- kill draksync patch (still need ?)
- disable dir-del patch, conflict with the acl one

* Sun Aug 06 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.8-3mdv2007.0
+ Revision: 53196
- ensure rsync is build with acl
- don't perform test on the cluster (see comment)
- remove changelog
- add patch to force nobody's group (#21340)
- inital rsync import

* Sun Jun 18 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.8-2mdv2007.0
- add patch to force nobody's group (#21340)

* Sun Apr 23 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.8-1mdk
- 2.6.8

* Fri Mar 17 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.7-2mdk
- path1: fix exclude with relative path (patch from rsync author)

* Sat Mar 11 2006 Olivier Thauvin <nanardon@mandriva.org> 2.6.7-1mdk
- 2.6.7

* Fri Jul 29 2005 Olivier Thauvin <nanardon@mandriva.org> 2.6.6-1mdk
- 2.6.6
- remove patch1, no longer need
- add --with --w/o patches options
- don't apply patches, test failed with acl patches (reported on the ML)

* Fri Jun 10 2005 Frederic Lepied <flepied@mandriva.com> 2.6.5-2mdk
- removed patch2 (not needed)

* Fri Jun 10 2005 Frederic Lepied <flepied@mandriva.com> 2.6.5-1mdk
- rediff patch2
- new release

* Thu Jun 09 2005 Olivier Thauvin <nanardon@mandriva.org> 2.6.4-2mdk
- apply 2 patches provide by rsync
- so fix #13854

* Thu May 05 2005 Olivier Thauvin <nanardon@mandriva.org> 2.6.4-1mdk
- 2.6.4
- make test in %%check

* Wed Nov 17 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.6.3-1mdk
- 2.6.3 final

* Thu Aug 19 2004 Warly <warly@mandrakesoft.com> 2.6.3-0.pre1.1mdk
- new version to fix security issue

* Mon Jun 21 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.6.2-2mdk
- security fix for CAN-2004-0426 (patch3) (Stew Benedict)
- misc spec file fixes

* Sun May 30 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.6.2-1mdk
- 2.6.2
- P2 from fedora:
	o Backport fix for crasher when passing multiple directories of the same
	  length (bug #123708)
- spec cosmetics

* Thu Jan 08 2004 Warly <warly@mandrakesoft.com> 2.6.0-1mdk
- new version

* Thu Dec 04 2003 Warly <warly@mandrakesoft.com> 2.5.7-1mdk
- new version (security fix)

